# Plugins

Plugins module for WordPress.

## Installation

Install the module

```bash
npm install @wordpress/plugins --save
```

_This package assumes that your code will run in an **ES2015+** environment. If you're using an environment that has limited or no support for ES2015+ such as lower versions of IE then using [core-js](https://github.com/zloirock/core-js) or [@babel/polyfill](https://babeljs.io/docs/en/next/babel-polyfill) will add support for these methods. Learn more about it in [Babel docs](https://babeljs.io/docs/en/next/caveats)._

### Plugins API

<!-- START TOKEN(Autogenerated API docs) -->

<a name="getPlugin" href="#getPlugin">#</a> **getPlugin**

Returns a registered plugin settings.

_Parameters_

-   _name_ `string`: Plugin name.

_Returns_

-   `?Object`: Plugin setting.

<a name="getPlugins" href="#getPlugins">#</a> **getPlugins**

Returns all registered plugins.

_Returns_

-   `Array`: Plugin settings.

<a name="PluginArea" href="#PluginArea">#</a> **PluginArea**

A component that renders all plugin fills in a hidden div.

_Usage_

```js
// Using ES5 syntax
var el = wp.element.createElement;
var PluginArea = wp.plugins.PluginArea;

function Layout() {
	return el(
		'div',
		{},
		'Content of the page',
		PluginArea
	);
}
```

```js
// Using ESNext syntax
const { PluginArea } = wp.plugins;

const Layout = () => (
	<div>
		Content of the page
		<PluginArea />
	</div>
);
```

_Returns_

-   `WPElement`: Plugin area.

<a name="registerPlugin" href="#registerPlugin">#</a> **registerPlugin**

Registers a plugin to the editor.

_Usage_

```js
// Using ES5 syntax
var el = wp.element.createElement;
var Fragment = wp.element.Fragment;
var PluginSidebar = wp.editPost.PluginSidebar;
var PluginSidebarMoreMenuItem = wp.editPost.PluginSidebarMoreMenuItem;
var registerPlugin = wp.plugins.registerPlugin;

function Component() {
	return el(
		Fragment,
		{},
		el(
			PluginSidebarMoreMenuItem,
			{
				target: 'sidebar-name',
			},
			'My Sidebar'
		),
		el(
			PluginSidebar,
			{
				name: 'sidebar-name',
				title: 'My Sidebar',
			},
			'Content of the sidebar'
		)
	);
}
registerPlugin( 'plugin-name', {
	icon: 'smiley',
	render: Component,
} );
```

```js
// Using ESNext syntax
const { PluginSidebar, PluginSidebarMoreMenuItem } = wp.editPost;
const { registerPlugin } = wp.plugins;

const Component = () => (
	<>
		<PluginSidebarMoreMenuItem
			target="sidebar-name"
		>
			My Sidebar
		</PluginSidebarMoreMenuItem>
		<PluginSidebar
			name="sidebar-name"
			title="My Sidebar"
		>
			Content of the sidebar
		</PluginSidebar>
	</>
);

registerPlugin( 'plugin-name', {
	icon: 'smiley',
	render: Component,
} );
```

_Parameters_

-   _name_ `string`: A string identifying the plugin. Must be unique across all registered plugins.
-   _settings_ `Object`: The settings for this plugin.
-   _settings.icon_ `(string|WPElement|Function)`: An icon to be shown in the UI. It can be a slug of the Dashicon, or an element (or function returning an element) if you choose to render your own SVG.
-   _settings.render_ `Function`: A component containing the UI elements to be rendered.

_Returns_

-   `Object`: The final plugin settings object.

<a name="unregisterPlugin" href="#unregisterPlugin">#</a> **unregisterPlugin**

Unregisters a plugin by name.

_Usage_

```js
// Using ES5 syntax
var unregisterPlugin = wp.plugins.unregisterPlugin;

unregisterPlugin( 'plugin-name' );
```

```js
// Using ESNext syntax
const { unregisterPlugin } = wp.plugins;

unregisterPlugin( 'plugin-name' );
```

_Parameters_

-   _name_ `string`: Plugin name.

_Returns_

-   `?WPPlugin`: The previous plugin settings object, if it has been successfully unregistered; otherwise `undefined`.

<a name="withPluginContext" href="#withPluginContext">#</a> **withPluginContext**

A Higher Order Component used to inject Plugin context to the
wrapped component.

_Parameters_

-   _mapContextToProps_ `Function`: Function called on every context change, expected to return object of props to merge with the component's own props.

_Returns_

-   `Component`: Enhanced component with injected context as props.


<!-- END TOKEN(Autogenerated API docs) -->

<br/><br/><p align="center"><img src="https://s.w.org/style/images/codeispoetry.png?1" alt="Code is Poetry." /></p>
